@@ -4,6 +4,7 @@ from diffpriv_laplace.query.sequential_statistics import (
     DiffPrivSequentialStatisticsQuery,
 )
 from diffpriv_laplace.query.parallel_statistics import DiffPrivParallelStatisticsQuery
+from diffpriv_laplace.laplace_sanitizer import DiffPrivLaplaceSanitizer
 from diffpriv_laplace.version import __version__
 
 __all__ = [
@@ -12,5 +13,6 @@ __all__ = [
     "DiffPrivStatisticKind",
     "DiffPrivSequentialStatisticsQuery",
     "DiffPrivParallelStatisticsQuery",
+    "DiffPrivLaplaceSanitizer",
     "__version__",
 ]
